@@ -18,7 +18,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 =head1 NAME
 
@@ -194,6 +194,7 @@ our @option_spec = (
     'max-time|m=s',
     'ntlm',
     'keepalive!',
+    'range=s',
     'request|X=s',
     'oauth2-bearer=s',
     'output|o=s',
@@ -507,6 +508,10 @@ sub _build_request( $self, $uri, $options, %build_options ) {
             $self->_add_header( \%headers, "Referer" => $options->{ 'referrer' } );
         };
 
+        if( defined $options->{ range }) {
+            $self->_add_header( \%headers, "Range" => $options->{ 'range' } );
+        };
+
         # We want to compare the headers case-insensitively
         my %headers_lc = map { lc $_ => 1 } keys %headers;
 
